Credits
-------

.. rst-class:: credits-list

- Michael Droettboom (founder)
- Pauli Virtanen

The rest of the contributors are listed in alphabetical order.

- Aaron Meurer
- @afragner
- Akihiro Nitta
- Andrew Nelson
- Andrew Thomas
- Antoine Pitrou
- Antony Lee
- Ariel Silvio Norberto RAMOS
- Arne Neumann
- Boris Feld
- Chiara Marmo
- Chris Beaumont
- Christoph Deil
- Christopher Whelan
- Colin Carroll
- Daniel Andres Pinto
- David Stansby
- Dieter Werthmüller
- Dorothy Kabarozi
- @DWesl
- Edison Gustavo Muenz
- Elliott Sales de Andrade
- Eric Dill
- Erik M. Bray
- Erik Tollerud
- Erwan Pannier
- Fangchen Li
- Hans Moritz Günther
- Isuru Fernando
- Jarrod Millman
- @jbrockmendel
- jeremie du boisberranger
- John Kirkham
- Josh Soref
- Juan Nunez-Iglesias
- Julian Rüth
- Kacper Kowalik
- Kacper Kowalik (Xarthisius)
- Kevin Anderson
- @Leenkiz
- Lucy Jiménez
- Marc Garcia
- @mariamadronah
- Mark Harfouche
- Markus Mohrhard
- Matthew Treinish
- Matthew Turk
- Matti Picus
- Mike Sarahan
- Min RK
- Nathan Goldbaum
- Nick Crews
- Nicole Franco León
- @pawel
- Paweł Redzyński
- Philippe Pepiot
- Pierre Glaser
- P. L. Lim
- Raphaël Gomès
- Richard Hattersley
- Rohit Goswami
- Rok Mihevc
- Sayed Adel
- serge-sans-paille
- Sourcery AI
- Thomas Pfaff
- Thomas Robitaille
- Tim Felgentreff
- Tom Augspurger
- Tushabe Catherine
- Tyler Reddy
- Valentin Haenel
- @Warbo
- Wojtek Ruszczewski
- Yaroslav Halchenko
- Zach Burnett
